"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.attachOnly = exports.deployOrAttach = void 0;
const typechain_1 = require("../typechain");
const hardhat_1 = require("hardhat");
const deployOrAttach = (contractName, FactoryConstructor, initialSigner) => {
    return {
        metadata: {
            contractName,
            bytecode: FactoryConstructor.bytecode
        },
        deploy: async (...args) => {
            const defaultSigner = initialSigner || (await hardhat_1.ethers.getSigners())[0];
            return new FactoryConstructor(defaultSigner).deploy(...(args || []));
        },
        attach: (0, exports.attachOnly)(FactoryConstructor, initialSigner).attach
    };
};
exports.deployOrAttach = deployOrAttach;
const attachOnly = (FactoryConstructor, initialSigner) => {
    return {
        attach: async (address, signer) => {
            const defaultSigner = initialSigner || (await hardhat_1.ethers.getSigners())[0];
            return new FactoryConstructor(signer || defaultSigner).attach(address);
        }
    };
};
exports.attachOnly = attachOnly;
const getContracts = (signer) => {
    return {
        // Link every contract to a default signer
        connect: (signer) => getContracts(signer),
        BancorNetwork: (0, exports.deployOrAttach)('BancorNetwork', typechain_1.BancorNetwork__factory, signer),
        BancorX: (0, exports.deployOrAttach)('BancorX', typechain_1.BancorX__factory, signer),
        CheckpointStore: (0, exports.deployOrAttach)('CheckpointStore', typechain_1.CheckpointStore__factory, signer),
        ContractRegistry: (0, exports.deployOrAttach)('ContractRegistry', typechain_1.ContractRegistry__factory, signer),
        ConversionPathFinder: (0, exports.deployOrAttach)('ConversionPathFinder', typechain_1.ConversionPathFinder__factory, signer),
        ConverterFactory: (0, exports.deployOrAttach)('ConverterFactory', typechain_1.ConverterFactory__factory, signer),
        ConverterRegistry: (0, exports.deployOrAttach)('ConverterRegistry', typechain_1.ConverterRegistry__factory, signer),
        ConverterRegistryData: (0, exports.deployOrAttach)('ConverterRegistryData', typechain_1.ConverterRegistryData__factory, signer),
        ConverterUpgrader: (0, exports.deployOrAttach)('ConverterUpgrader', typechain_1.ConverterUpgrader__factory, signer),
        ConverterV27OrLowerWithFallback: (0, exports.deployOrAttach)('ConverterV27OrLowerWithFallback', typechain_1.ConverterV27OrLowerWithFallback__factory, signer),
        ConverterV27OrLowerWithoutFallback: (0, exports.deployOrAttach)('ConverterV27OrLowerWithoutFallback', typechain_1.ConverterV27OrLowerWithoutFallback__factory, signer),
        ConverterV28OrHigherWithFallback: (0, exports.deployOrAttach)('ConverterV28OrHigherWithFallback', typechain_1.ConverterV28OrHigherWithFallback__factory, signer),
        ConverterV28OrHigherWithoutFallback: (0, exports.deployOrAttach)('ConverterV28OrHigherWithoutFallback', typechain_1.ConverterV28OrHigherWithoutFallback__factory, signer),
        DSToken: (0, exports.deployOrAttach)('DSToken', typechain_1.DSToken__factory, signer),
        ERC20: (0, exports.deployOrAttach)('ERC20', typechain_1.ERC20__factory, signer),
        LiquidityProtection: (0, exports.deployOrAttach)('LiquidityProtection', typechain_1.LiquidityProtection__factory, signer),
        LiquidityProtectionSettings: (0, exports.deployOrAttach)('LiquidityProtectionSettings', typechain_1.LiquidityProtectionSettings__factory, signer),
        LiquidityProtectionStats: (0, exports.deployOrAttach)('LiquidityProtectionStats', typechain_1.LiquidityProtectionStats__factory, signer),
        LiquidityProtectionStore: (0, exports.deployOrAttach)('LiquidityProtectionStore', typechain_1.LiquidityProtectionStore__factory, signer),
        LiquidityProtectionSystemStore: (0, exports.deployOrAttach)('LiquidityProtectionSystemStore', typechain_1.LiquidityProtectionSystemStore__factory, signer),
        MockVortexBurner: (0, exports.deployOrAttach)('MockVortexBurner', typechain_1.MockVortexBurner__factory, signer),
        NetworkSettings: (0, exports.deployOrAttach)('NetworkSettings', typechain_1.NetworkSettings__factory, signer),
        Owned: (0, exports.deployOrAttach)('Owned', typechain_1.Owned__factory, signer),
        StakingRewards: (0, exports.deployOrAttach)('StakingRewards', typechain_1.StakingRewards__factory, signer),
        StakingRewardsClaim: (0, exports.deployOrAttach)('StakingRewardsClaim', typechain_1.StakingRewardsClaim__factory, signer),
        StakingRewardsStore: (0, exports.deployOrAttach)('StakingRewardsStore', typechain_1.StakingRewardsStore__factory, signer),
        StandardPoolConverter: (0, exports.deployOrAttach)('StandardPoolConverter', typechain_1.StandardPoolConverter__factory, signer),
        StandardPoolConverterFactory: (0, exports.deployOrAttach)('StandardPoolConverterFactory', typechain_1.StandardPoolConverterFactory__factory, signer),
        TestBancorNetwork: (0, exports.deployOrAttach)('TestBancorNetwork', typechain_1.TestBancorNetwork__factory, signer),
        TestBancorNetworkV3: (0, exports.deployOrAttach)('TestBancorNetworkV3', typechain_1.TestBancorNetworkV3__factory, signer),
        TestCheckpointStore: (0, exports.deployOrAttach)('TestCheckpointStore', typechain_1.TestCheckpointStore__factory, signer),
        TestContractRegistryClient: (0, exports.deployOrAttach)('TestContractRegistryClient', typechain_1.TestContractRegistryClient__factory, signer),
        TestConverterFactory: (0, exports.deployOrAttach)('TestConverterFactory', typechain_1.TestConverterFactory__factory, signer),
        TestConverterRegistry: (0, exports.deployOrAttach)('TestConverterRegistry', typechain_1.TestConverterRegistry__factory, signer),
        TestLiquidityProtection: (0, exports.deployOrAttach)('TestLiquidityProtection', typechain_1.TestLiquidityProtection__factory, signer),
        TestLiquidityProvisionEventsSubscriber: (0, exports.deployOrAttach)('TestLiquidityProvisionEventsSubscriber', typechain_1.TestLiquidityProvisionEventsSubscriber__factory, signer),
        TestMathEx: (0, exports.deployOrAttach)('TestMathEx', typechain_1.TestMathEx__factory, signer),
        TestNonStandardToken: (0, exports.deployOrAttach)('TestNonStandardToken', typechain_1.TestNonStandardToken__factory, signer),
        TestReserveToken: (0, exports.deployOrAttach)('TestReserveToken', typechain_1.TestReserveToken__factory, signer),
        TestSafeERC20Ex: (0, exports.deployOrAttach)('TestSafeERC20Ex', typechain_1.TestSafeERC20Ex__factory, signer),
        TestStakingRewards: (0, exports.deployOrAttach)('TestStakingRewards', typechain_1.TestStakingRewards__factory, signer),
        TestStakingRewardsStore: (0, exports.deployOrAttach)('TestStakingRewardsStore', typechain_1.TestStakingRewardsStore__factory, signer),
        TestStandardPoolConverter: (0, exports.deployOrAttach)('TestStandardPoolConverter', typechain_1.TestStandardPoolConverter__factory, signer),
        TestStandardPoolConverterFactory: (0, exports.deployOrAttach)('TestStandardPoolConverterFactory', typechain_1.TestStandardPoolConverterFactory__factory, signer),
        TestStandardToken: (0, exports.deployOrAttach)('TestStandardToken', typechain_1.TestStandardToken__factory, signer),
        TestTokenGovernance: (0, exports.deployOrAttach)('TestTokenGovernance', typechain_1.TestTokenGovernance__factory, signer),
        TestTransferPositionCallback: (0, exports.deployOrAttach)('TestTransferPositionCallback', typechain_1.TestTransferPositionCallback__factory, signer),
        TestTypedConverterAnchorFactory: (0, exports.deployOrAttach)('TestTypedConverterAnchorFactory', typechain_1.TestTypedConverterAnchorFactory__factory, signer),
        TokenGovernance: (0, exports.deployOrAttach)('TokenGovernance', typechain_1.TokenGovernance__factory, signer),
        TokenHolder: (0, exports.deployOrAttach)('TokenHolder', typechain_1.TokenHolder__factory, signer),
        VortexBurner: (0, exports.deployOrAttach)('VortexBurner', typechain_1.VortexBurner__factory, signer)
    };
};
exports.default = getContracts();
//# sourceMappingURL=Contracts.js.map