"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
require("@nomiclabs/hardhat-ethers");
require("@nomiclabs/hardhat-etherscan");
require("@nomiclabs/hardhat-waffle");
require("@typechain/hardhat");
const fs_1 = __importDefault(require("fs"));
require("hardhat-contract-sizer");
const path_1 = __importDefault(require("path"));
require("solidity-coverage");
const configPath = path_1.default.join(__dirname, '/config.json');
const configFile = fs_1.default.existsSync(configPath) ? JSON.parse(fs_1.default.readFileSync(configPath, 'utf8')) : {};
const loadAPIKey = (apiKeyName) => {
    return configFile.apiKeys ? (configFile.apiKeys[apiKeyName] ? configFile.apiKeys[apiKeyName] : '') : '';
};
// Casting to unknown assume the good type is provided
const loadENVKey = (envKeyName) => {
    return process.env[envKeyName];
};
const configNetworks = configFile.networks || {};
const config = {
    networks: {
        hardhat: {
            gasPrice: 20000000000,
            gas: 9500000,
            accounts: {
                count: 10,
                accountsBalance: '10000000000000000000000000000'
            },
            allowUnlimitedContractSize: true
        },
        mainnet: {
            url: ''
        },
        ...configNetworks
    },
    typechain: {
        outDir: 'typechain',
        target: 'ethers-v5'
    },
    solidity: {
        compilers: [
            {
                version: '0.6.12',
                settings: {
                    optimizer: {
                        enabled: true,
                        runs: 200
                    },
                    metadata: {
                        bytecodeHash: 'none'
                    }
                }
            },
            {
                version: '0.8.13',
                settings: {
                    optimizer: {
                        enabled: true,
                        runs: 200
                    },
                    metadata: {
                        bytecodeHash: 'none'
                    }
                }
            }
        ]
    },
    contractSizer: {
        alphaSort: true,
        runOnCompile: false,
        disambiguatePaths: false
    },
    mocha: {
        timeout: 600000,
        color: true,
        bail: loadENVKey('BAIL')
    },
    etherscan: {
        apiKey: ''
    }
};
exports.default = config;
//# sourceMappingURL=hardhat.config.js.map