import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface ConverterUpgraderInterface extends utils.Interface {
    functions: {
        "acceptOwnership()": FunctionFragment;
        "newOwner()": FunctionFragment;
        "onlyOwnerCanUpdateRegistry()": FunctionFragment;
        "owner()": FunctionFragment;
        "prevRegistry()": FunctionFragment;
        "registry()": FunctionFragment;
        "restoreRegistry()": FunctionFragment;
        "restrictRegistryUpdate(bool)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "updateRegistry()": FunctionFragment;
        "upgrade(uint16)": FunctionFragment;
        "upgradeOld(address,bytes32)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "acceptOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "newOwner", values?: undefined): string;
    encodeFunctionData(functionFragment: "onlyOwnerCanUpdateRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "prevRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "registry", values?: undefined): string;
    encodeFunctionData(functionFragment: "restoreRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "restrictRegistryUpdate", values: [boolean]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "updateRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "upgrade", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "upgradeOld", values: [string, BytesLike]): string;
    decodeFunctionResult(functionFragment: "acceptOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "newOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onlyOwnerCanUpdateRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "prevRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "registry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "restoreRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "restrictRegistryUpdate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgrade", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeOld", data: BytesLike): Result;
    events: {
        "ConverterOwned(address,address)": EventFragment;
        "ConverterUpgrade(address,address)": EventFragment;
        "OwnerUpdate(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ConverterOwned"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ConverterUpgrade"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnerUpdate"): EventFragment;
}
export declare type ConverterOwnedEvent = TypedEvent<[
    string,
    string
], {
    converter: string;
    owner: string;
}>;
export declare type ConverterOwnedEventFilter = TypedEventFilter<ConverterOwnedEvent>;
export declare type ConverterUpgradeEvent = TypedEvent<[
    string,
    string
], {
    oldConverter: string;
    newConverter: string;
}>;
export declare type ConverterUpgradeEventFilter = TypedEventFilter<ConverterUpgradeEvent>;
export declare type OwnerUpdateEvent = TypedEvent<[
    string,
    string
], {
    prevOwner: string;
    newOwner: string;
}>;
export declare type OwnerUpdateEventFilter = TypedEventFilter<OwnerUpdateEvent>;
export interface ConverterUpgrader extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ConverterUpgraderInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        newOwner(overrides?: CallOverrides): Promise<[string]>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<[boolean]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        prevRegistry(overrides?: CallOverrides): Promise<[string]>;
        registry(overrides?: CallOverrides): Promise<[string]>;
        restoreRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        "upgrade(uint16)"(version: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        "upgrade(bytes32)"(version: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeOld(converter: string, arg1: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    acceptOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    newOwner(overrides?: CallOverrides): Promise<string>;
    onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<boolean>;
    owner(overrides?: CallOverrides): Promise<string>;
    prevRegistry(overrides?: CallOverrides): Promise<string>;
    registry(overrides?: CallOverrides): Promise<string>;
    restoreRegistry(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateRegistry(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    "upgrade(uint16)"(version: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    "upgrade(bytes32)"(version: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeOld(converter: string, arg1: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        acceptOwnership(overrides?: CallOverrides): Promise<void>;
        newOwner(overrides?: CallOverrides): Promise<string>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<boolean>;
        owner(overrides?: CallOverrides): Promise<string>;
        prevRegistry(overrides?: CallOverrides): Promise<string>;
        registry(overrides?: CallOverrides): Promise<string>;
        restoreRegistry(overrides?: CallOverrides): Promise<void>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        updateRegistry(overrides?: CallOverrides): Promise<void>;
        "upgrade(uint16)"(version: BigNumberish, overrides?: CallOverrides): Promise<void>;
        "upgrade(bytes32)"(version: BytesLike, overrides?: CallOverrides): Promise<void>;
        upgradeOld(converter: string, arg1: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ConverterOwned(address,address)"(converter?: string | null, owner?: string | null): ConverterOwnedEventFilter;
        ConverterOwned(converter?: string | null, owner?: string | null): ConverterOwnedEventFilter;
        "ConverterUpgrade(address,address)"(oldConverter?: string | null, newConverter?: string | null): ConverterUpgradeEventFilter;
        ConverterUpgrade(oldConverter?: string | null, newConverter?: string | null): ConverterUpgradeEventFilter;
        "OwnerUpdate(address,address)"(prevOwner?: string | null, newOwner?: string | null): OwnerUpdateEventFilter;
        OwnerUpdate(prevOwner?: string | null, newOwner?: string | null): OwnerUpdateEventFilter;
    };
    estimateGas: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        newOwner(overrides?: CallOverrides): Promise<BigNumber>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        prevRegistry(overrides?: CallOverrides): Promise<BigNumber>;
        registry(overrides?: CallOverrides): Promise<BigNumber>;
        restoreRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        "upgrade(uint16)"(version: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        "upgrade(bytes32)"(version: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeOld(converter: string, arg1: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        newOwner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        prevRegistry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        registry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        restoreRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        "upgrade(uint16)"(version: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        "upgrade(bytes32)"(version: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeOld(converter: string, arg1: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=ConverterUpgrader.d.ts.map