import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface IBancorNetworkInterface extends utils.Interface {
    functions: {
        "convertByPath(address[],uint256,uint256,address,address,uint256)": FunctionFragment;
        "rateByPath(address[],uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "convertByPath", values: [string[], BigNumberish, BigNumberish, string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "rateByPath", values: [string[], BigNumberish]): string;
    decodeFunctionResult(functionFragment: "convertByPath", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rateByPath", data: BytesLike): Result;
    events: {};
}
export interface IBancorNetwork extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IBancorNetworkInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        convertByPath(path: string[], sourceAmount: BigNumberish, minReturn: BigNumberish, beneficiary: string, affiliateAccount: string, affiliateFee: BigNumberish, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        rateByPath(path: string[], sourceAmount: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    convertByPath(path: string[], sourceAmount: BigNumberish, minReturn: BigNumberish, beneficiary: string, affiliateAccount: string, affiliateFee: BigNumberish, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    rateByPath(path: string[], sourceAmount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        convertByPath(path: string[], sourceAmount: BigNumberish, minReturn: BigNumberish, beneficiary: string, affiliateAccount: string, affiliateFee: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        rateByPath(path: string[], sourceAmount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {};
    estimateGas: {
        convertByPath(path: string[], sourceAmount: BigNumberish, minReturn: BigNumberish, beneficiary: string, affiliateAccount: string, affiliateFee: BigNumberish, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        rateByPath(path: string[], sourceAmount: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        convertByPath(path: string[], sourceAmount: BigNumberish, minReturn: BigNumberish, beneficiary: string, affiliateAccount: string, affiliateFee: BigNumberish, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        rateByPath(path: string[], sourceAmount: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=IBancorNetwork.d.ts.map