import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface ICheckpointStoreInterface extends utils.Interface {
    functions: {
        "addCheckpoint(address)": FunctionFragment;
        "addPastCheckpoint(address,uint256)": FunctionFragment;
        "addPastCheckpoints(address[],uint256[])": FunctionFragment;
        "checkpoint(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "addCheckpoint", values: [string]): string;
    encodeFunctionData(functionFragment: "addPastCheckpoint", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "addPastCheckpoints", values: [string[], BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "checkpoint", values: [string]): string;
    decodeFunctionResult(functionFragment: "addCheckpoint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addPastCheckpoint", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addPastCheckpoints", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "checkpoint", data: BytesLike): Result;
    events: {};
}
export interface ICheckpointStore extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ICheckpointStoreInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        addCheckpoint(target: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        addPastCheckpoint(target: string, timestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        addPastCheckpoints(targets: string[], timestamps: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        checkpoint(target: string, overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    addCheckpoint(target: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    addPastCheckpoint(target: string, timestamp: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    addPastCheckpoints(targets: string[], timestamps: BigNumberish[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    checkpoint(target: string, overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        addCheckpoint(target: string, overrides?: CallOverrides): Promise<void>;
        addPastCheckpoint(target: string, timestamp: BigNumberish, overrides?: CallOverrides): Promise<void>;
        addPastCheckpoints(targets: string[], timestamps: BigNumberish[], overrides?: CallOverrides): Promise<void>;
        checkpoint(target: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {};
    estimateGas: {
        addCheckpoint(target: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        addPastCheckpoint(target: string, timestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        addPastCheckpoints(targets: string[], timestamps: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        checkpoint(target: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        addCheckpoint(target: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        addPastCheckpoint(target: string, timestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        addPastCheckpoints(targets: string[], timestamps: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        checkpoint(target: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=ICheckpointStore.d.ts.map