import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface ILiquidityProtectionStoreInterface extends utils.Interface {
    functions: {
        "acceptOwnership()": FunctionFragment;
        "addLockedBalance(address,uint256,uint256)": FunctionFragment;
        "addProtectedLiquidity(address,address,address,uint256,uint256,uint256,uint256,uint256)": FunctionFragment;
        "decSystemBalance(address,uint256)": FunctionFragment;
        "incSystemBalance(address,uint256)": FunctionFragment;
        "lockedBalance(address,uint256)": FunctionFragment;
        "lockedBalanceRange(address,uint256,uint256)": FunctionFragment;
        "owner()": FunctionFragment;
        "protectedLiquidity(uint256)": FunctionFragment;
        "removeLockedBalance(address,uint256)": FunctionFragment;
        "removeProtectedLiquidity(uint256)": FunctionFragment;
        "systemBalance(address)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "updateProtectedLiquidityAmounts(uint256,uint256,uint256)": FunctionFragment;
        "withdrawTokens(address,address,uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "acceptOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "addLockedBalance", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "addProtectedLiquidity", values: [
        string,
        string,
        string,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish
    ]): string;
    encodeFunctionData(functionFragment: "decSystemBalance", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "incSystemBalance", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "lockedBalance", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "lockedBalanceRange", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "protectedLiquidity", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "removeLockedBalance", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "removeProtectedLiquidity", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "systemBalance", values: [string]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "updateProtectedLiquidityAmounts", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "withdrawTokens", values: [string, string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "acceptOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addLockedBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addProtectedLiquidity", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "decSystemBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "incSystemBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lockedBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lockedBalanceRange", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "protectedLiquidity", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeLockedBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeProtectedLiquidity", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "systemBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateProtectedLiquidityAmounts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdrawTokens", data: BytesLike): Result;
    events: {};
}
export interface ILiquidityProtectionStore extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ILiquidityProtectionStoreInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        addLockedBalance(provider: string, reserveAmount: BigNumberish, expirationTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        addProtectedLiquidity(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, reserveRateN: BigNumberish, reserveRateD: BigNumberish, timestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        decSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        incSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        lockedBalance(provider: string, index: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber]>;
        lockedBalanceRange(provider: string, startIndex: BigNumberish, endIndex: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber[], BigNumber[]]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        protectedLiquidity(id: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            string,
            string,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ]>;
        removeLockedBalance(provider: string, index: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        removeProtectedLiquidity(id: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        systemBalance(poolToken: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateProtectedLiquidityAmounts(id: BigNumberish, poolNewAmount: BigNumberish, reserveNewAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        withdrawTokens(token: string, recipient: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    acceptOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    addLockedBalance(provider: string, reserveAmount: BigNumberish, expirationTime: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    addProtectedLiquidity(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, reserveRateN: BigNumberish, reserveRateD: BigNumberish, timestamp: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    decSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    incSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    lockedBalance(provider: string, index: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber]>;
    lockedBalanceRange(provider: string, startIndex: BigNumberish, endIndex: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber[], BigNumber[]]>;
    owner(overrides?: CallOverrides): Promise<string>;
    protectedLiquidity(id: BigNumberish, overrides?: CallOverrides): Promise<[
        string,
        string,
        string,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber,
        BigNumber
    ]>;
    removeLockedBalance(provider: string, index: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    removeProtectedLiquidity(id: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    systemBalance(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateProtectedLiquidityAmounts(id: BigNumberish, poolNewAmount: BigNumberish, reserveNewAmount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    withdrawTokens(token: string, recipient: string, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        acceptOwnership(overrides?: CallOverrides): Promise<void>;
        addLockedBalance(provider: string, reserveAmount: BigNumberish, expirationTime: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        addProtectedLiquidity(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, reserveRateN: BigNumberish, reserveRateD: BigNumberish, timestamp: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        decSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        incSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        lockedBalance(provider: string, index: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber, BigNumber]>;
        lockedBalanceRange(provider: string, startIndex: BigNumberish, endIndex: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber[], BigNumber[]]>;
        owner(overrides?: CallOverrides): Promise<string>;
        protectedLiquidity(id: BigNumberish, overrides?: CallOverrides): Promise<[
            string,
            string,
            string,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber,
            BigNumber
        ]>;
        removeLockedBalance(provider: string, index: BigNumberish, overrides?: CallOverrides): Promise<void>;
        removeProtectedLiquidity(id: BigNumberish, overrides?: CallOverrides): Promise<void>;
        systemBalance(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        updateProtectedLiquidityAmounts(id: BigNumberish, poolNewAmount: BigNumberish, reserveNewAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        withdrawTokens(token: string, recipient: string, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        addLockedBalance(provider: string, reserveAmount: BigNumberish, expirationTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        addProtectedLiquidity(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, reserveRateN: BigNumberish, reserveRateD: BigNumberish, timestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        decSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        incSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        lockedBalance(provider: string, index: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        lockedBalanceRange(provider: string, startIndex: BigNumberish, endIndex: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        protectedLiquidity(id: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        removeLockedBalance(provider: string, index: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        removeProtectedLiquidity(id: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        systemBalance(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateProtectedLiquidityAmounts(id: BigNumberish, poolNewAmount: BigNumberish, reserveNewAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        withdrawTokens(token: string, recipient: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        addLockedBalance(provider: string, reserveAmount: BigNumberish, expirationTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        addProtectedLiquidity(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, reserveRateN: BigNumberish, reserveRateD: BigNumberish, timestamp: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        decSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        incSystemBalance(poolToken: string, poolAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        lockedBalance(provider: string, index: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        lockedBalanceRange(provider: string, startIndex: BigNumberish, endIndex: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        protectedLiquidity(id: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        removeLockedBalance(provider: string, index: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        removeProtectedLiquidity(id: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        systemBalance(poolToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateProtectedLiquidityAmounts(id: BigNumberish, poolNewAmount: BigNumberish, reserveNewAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        withdrawTokens(token: string, recipient: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=ILiquidityProtectionStore.d.ts.map