import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface TestConverterFactoryInterface extends utils.Interface {
    functions: {
        "acceptOwnership()": FunctionFragment;
        "anchorFactories(uint16)": FunctionFragment;
        "converterFactories(uint16)": FunctionFragment;
        "createAnchor(uint16,string,string,uint8)": FunctionFragment;
        "createConverter(uint16,address,address,uint32)": FunctionFragment;
        "createdAnchor()": FunctionFragment;
        "createdConverter()": FunctionFragment;
        "newOwner()": FunctionFragment;
        "owner()": FunctionFragment;
        "registerTypedConverterAnchorFactory(address)": FunctionFragment;
        "registerTypedConverterFactory(address)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "unregisterTypedConverterAnchorFactory(address)": FunctionFragment;
        "unregisterTypedConverterFactory(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "acceptOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "anchorFactories", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "converterFactories", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "createAnchor", values: [BigNumberish, string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "createConverter", values: [BigNumberish, string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "createdAnchor", values?: undefined): string;
    encodeFunctionData(functionFragment: "createdConverter", values?: undefined): string;
    encodeFunctionData(functionFragment: "newOwner", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "registerTypedConverterAnchorFactory", values: [string]): string;
    encodeFunctionData(functionFragment: "registerTypedConverterFactory", values: [string]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "unregisterTypedConverterAnchorFactory", values: [string]): string;
    encodeFunctionData(functionFragment: "unregisterTypedConverterFactory", values: [string]): string;
    decodeFunctionResult(functionFragment: "acceptOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "anchorFactories", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "converterFactories", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createAnchor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createConverter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createdAnchor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createdConverter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "newOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "registerTypedConverterAnchorFactory", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "registerTypedConverterFactory", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unregisterTypedConverterAnchorFactory", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unregisterTypedConverterFactory", data: BytesLike): Result;
    events: {
        "NewConverter(uint16,address,address)": EventFragment;
        "OwnerUpdate(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "NewConverter"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnerUpdate"): EventFragment;
}
export declare type NewConverterEvent = TypedEvent<[
    number,
    string,
    string
], {
    converterType: number;
    converter: string;
    converterOwner: string;
}>;
export declare type NewConverterEventFilter = TypedEventFilter<NewConverterEvent>;
export declare type OwnerUpdateEvent = TypedEvent<[
    string,
    string
], {
    prevOwner: string;
    newOwner: string;
}>;
export declare type OwnerUpdateEventFilter = TypedEventFilter<OwnerUpdateEvent>;
export interface TestConverterFactory extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: TestConverterFactoryInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        anchorFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        converterFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        createAnchor(converterType: BigNumberish, name: string, symbol: string, decimals: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        createConverter(converterType: BigNumberish, anchor: string, registry: string, maxConversionFee: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        createdAnchor(overrides?: CallOverrides): Promise<[string]>;
        createdConverter(overrides?: CallOverrides): Promise<[string]>;
        newOwner(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        registerTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        registerTypedConverterFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        unregisterTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        unregisterTypedConverterFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    acceptOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    anchorFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<string>;
    converterFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<string>;
    createAnchor(converterType: BigNumberish, name: string, symbol: string, decimals: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    createConverter(converterType: BigNumberish, anchor: string, registry: string, maxConversionFee: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    createdAnchor(overrides?: CallOverrides): Promise<string>;
    createdConverter(overrides?: CallOverrides): Promise<string>;
    newOwner(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    registerTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    registerTypedConverterFactory(factory: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    unregisterTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    unregisterTypedConverterFactory(factory: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        acceptOwnership(overrides?: CallOverrides): Promise<void>;
        anchorFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<string>;
        converterFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<string>;
        createAnchor(converterType: BigNumberish, name: string, symbol: string, decimals: BigNumberish, overrides?: CallOverrides): Promise<string>;
        createConverter(converterType: BigNumberish, anchor: string, registry: string, maxConversionFee: BigNumberish, overrides?: CallOverrides): Promise<string>;
        createdAnchor(overrides?: CallOverrides): Promise<string>;
        createdConverter(overrides?: CallOverrides): Promise<string>;
        newOwner(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        registerTypedConverterAnchorFactory(factory: string, overrides?: CallOverrides): Promise<void>;
        registerTypedConverterFactory(factory: string, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        unregisterTypedConverterAnchorFactory(factory: string, overrides?: CallOverrides): Promise<void>;
        unregisterTypedConverterFactory(factory: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "NewConverter(uint16,address,address)"(converterType?: BigNumberish | null, converter?: string | null, converterOwner?: string | null): NewConverterEventFilter;
        NewConverter(converterType?: BigNumberish | null, converter?: string | null, converterOwner?: string | null): NewConverterEventFilter;
        "OwnerUpdate(address,address)"(prevOwner?: string | null, newOwner?: string | null): OwnerUpdateEventFilter;
        OwnerUpdate(prevOwner?: string | null, newOwner?: string | null): OwnerUpdateEventFilter;
    };
    estimateGas: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        anchorFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        converterFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        createAnchor(converterType: BigNumberish, name: string, symbol: string, decimals: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        createConverter(converterType: BigNumberish, anchor: string, registry: string, maxConversionFee: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        createdAnchor(overrides?: CallOverrides): Promise<BigNumber>;
        createdConverter(overrides?: CallOverrides): Promise<BigNumber>;
        newOwner(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        registerTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        registerTypedConverterFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        unregisterTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        unregisterTypedConverterFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        anchorFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        converterFactories(converterType: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        createAnchor(converterType: BigNumberish, name: string, symbol: string, decimals: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        createConverter(converterType: BigNumberish, anchor: string, registry: string, maxConversionFee: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        createdAnchor(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        createdConverter(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        newOwner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        registerTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        registerTypedConverterFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        unregisterTypedConverterAnchorFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        unregisterTypedConverterFactory(factory: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=TestConverterFactory.d.ts.map