import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
export interface ILiquidityProtectionStatsInterface extends utils.Interface {
    functions: {
        "addProviderPool(address,address)": FunctionFragment;
        "decreaseTotalAmounts(address,address,address,uint256,uint256)": FunctionFragment;
        "increaseTotalAmounts(address,address,address,uint256,uint256)": FunctionFragment;
        "providerPools(address)": FunctionFragment;
        "removeProviderPool(address,address)": FunctionFragment;
        "totalPoolAmount(address)": FunctionFragment;
        "totalProviderAmount(address,address,address)": FunctionFragment;
        "totalReserveAmount(address,address)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "addProviderPool" | "decreaseTotalAmounts" | "increaseTotalAmounts" | "providerPools" | "removeProviderPool" | "totalPoolAmount" | "totalProviderAmount" | "totalReserveAmount"): FunctionFragment;
    encodeFunctionData(functionFragment: "addProviderPool", values: [string, string]): string;
    encodeFunctionData(functionFragment: "decreaseTotalAmounts", values: [string, string, string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "increaseTotalAmounts", values: [string, string, string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "providerPools", values: [string]): string;
    encodeFunctionData(functionFragment: "removeProviderPool", values: [string, string]): string;
    encodeFunctionData(functionFragment: "totalPoolAmount", values: [string]): string;
    encodeFunctionData(functionFragment: "totalProviderAmount", values: [string, string, string]): string;
    encodeFunctionData(functionFragment: "totalReserveAmount", values: [string, string]): string;
    decodeFunctionResult(functionFragment: "addProviderPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "decreaseTotalAmounts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "increaseTotalAmounts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "providerPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeProviderPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalPoolAmount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalProviderAmount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalReserveAmount", data: BytesLike): Result;
    events: {};
}
export interface ILiquidityProtectionStats extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ILiquidityProtectionStatsInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        addProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        decreaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        increaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        providerPools(provider: string, overrides?: CallOverrides): Promise<[string[]]>;
        removeProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        totalPoolAmount(poolToken: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        totalProviderAmount(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        totalReserveAmount(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    addProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    decreaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    increaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    providerPools(provider: string, overrides?: CallOverrides): Promise<string[]>;
    removeProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    totalPoolAmount(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    totalProviderAmount(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    totalReserveAmount(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        addProviderPool(provider: string, poolToken: string, overrides?: CallOverrides): Promise<boolean>;
        decreaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        increaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        providerPools(provider: string, overrides?: CallOverrides): Promise<string[]>;
        removeProviderPool(provider: string, poolToken: string, overrides?: CallOverrides): Promise<boolean>;
        totalPoolAmount(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        totalProviderAmount(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        totalReserveAmount(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {};
    estimateGas: {
        addProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        decreaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        increaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        providerPools(provider: string, overrides?: CallOverrides): Promise<BigNumber>;
        removeProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        totalPoolAmount(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        totalProviderAmount(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        totalReserveAmount(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        addProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        decreaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        increaseTotalAmounts(provider: string, poolToken: string, reserveToken: string, poolAmount: BigNumberish, reserveAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        providerPools(provider: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        removeProviderPool(provider: string, poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        totalPoolAmount(poolToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        totalProviderAmount(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        totalReserveAmount(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=ILiquidityProtectionStats.d.ts.map