import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
import type { FunctionFragment, Result } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
export interface IStakingRewardsStoreInterface extends utils.Interface {
    functions: {
        "addPoolProgram(address,address[2],uint32[2],uint256,uint256)": FunctionFragment;
        "isPoolParticipating(address)": FunctionFragment;
        "isReserveParticipating(address,address)": FunctionFragment;
        "poolProgram(address)": FunctionFragment;
        "poolPrograms()": FunctionFragment;
        "poolRewards(address,address)": FunctionFragment;
        "providerLastClaimTime(address)": FunctionFragment;
        "providerRewards(address,address,address)": FunctionFragment;
        "removePoolProgram(address)": FunctionFragment;
        "setPoolProgramEndTime(address,uint256)": FunctionFragment;
        "updatePoolRewardsData(address,address,uint256,uint256,uint256)": FunctionFragment;
        "updateProviderLastClaimTime(address)": FunctionFragment;
        "updateProviderRewardsData(address,address,address,uint256,uint256,uint256,uint256,uint256,uint32)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "addPoolProgram" | "isPoolParticipating" | "isReserveParticipating" | "poolProgram" | "poolPrograms" | "poolRewards" | "providerLastClaimTime" | "providerRewards" | "removePoolProgram" | "setPoolProgramEndTime" | "updatePoolRewardsData" | "updateProviderLastClaimTime" | "updateProviderRewardsData"): FunctionFragment;
    encodeFunctionData(functionFragment: "addPoolProgram", values: [
        string,
        [
            string,
            string
        ],
        [
            BigNumberish,
            BigNumberish
        ],
        BigNumberish,
        BigNumberish
    ]): string;
    encodeFunctionData(functionFragment: "isPoolParticipating", values: [string]): string;
    encodeFunctionData(functionFragment: "isReserveParticipating", values: [string, string]): string;
    encodeFunctionData(functionFragment: "poolProgram", values: [string]): string;
    encodeFunctionData(functionFragment: "poolPrograms", values?: undefined): string;
    encodeFunctionData(functionFragment: "poolRewards", values: [string, string]): string;
    encodeFunctionData(functionFragment: "providerLastClaimTime", values: [string]): string;
    encodeFunctionData(functionFragment: "providerRewards", values: [string, string, string]): string;
    encodeFunctionData(functionFragment: "removePoolProgram", values: [string]): string;
    encodeFunctionData(functionFragment: "setPoolProgramEndTime", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "updatePoolRewardsData", values: [string, string, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "updateProviderLastClaimTime", values: [string]): string;
    encodeFunctionData(functionFragment: "updateProviderRewardsData", values: [
        string,
        string,
        string,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        BigNumberish
    ]): string;
    decodeFunctionResult(functionFragment: "addPoolProgram", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isPoolParticipating", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isReserveParticipating", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "poolProgram", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "poolPrograms", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "poolRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "providerLastClaimTime", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "providerRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removePoolProgram", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPoolProgramEndTime", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updatePoolRewardsData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateProviderLastClaimTime", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateProviderRewardsData", data: BytesLike): Result;
    events: {};
}
export interface IStakingRewardsStore extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IStakingRewardsStoreInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        addPoolProgram(poolToken: string, reserveTokens: [string, string], rewardShares: [BigNumberish, BigNumberish], endTime: BigNumberish, rewardRate: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        isPoolParticipating(poolToken: string, overrides?: CallOverrides): Promise<[boolean]>;
        isReserveParticipating(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[boolean]>;
        poolProgram(poolToken: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            BigNumber,
            [string, string],
            [number, number]
        ]>;
        poolPrograms(overrides?: CallOverrides): Promise<[
            string[],
            BigNumber[],
            BigNumber[],
            BigNumber[],
            [
                string,
                string
            ][],
            [
                number,
                number
            ][]
        ]>;
        poolRewards(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber]>;
        providerLastClaimTime(provider: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        providerRewards(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber, BigNumber, BigNumber, number]>;
        removePoolProgram(poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPoolProgramEndTime(poolToken: string, newEndTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updatePoolRewardsData(poolToken: string, reserveToken: string, lastUpdateTime: BigNumberish, rewardPerToken: BigNumberish, totalClaimedRewards: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateProviderLastClaimTime(provider: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateProviderRewardsData(provider: string, poolToken: string, reserveToken: string, rewardPerToken: BigNumberish, pendingBaseRewards: BigNumberish, totalClaimedRewards: BigNumberish, effectiveStakingTime: BigNumberish, baseRewardsDebt: BigNumberish, baseRewardsDebtMultiplier: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    addPoolProgram(poolToken: string, reserveTokens: [string, string], rewardShares: [BigNumberish, BigNumberish], endTime: BigNumberish, rewardRate: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    isPoolParticipating(poolToken: string, overrides?: CallOverrides): Promise<boolean>;
    isReserveParticipating(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<boolean>;
    poolProgram(poolToken: string, overrides?: CallOverrides): Promise<[
        BigNumber,
        BigNumber,
        BigNumber,
        [string, string],
        [number, number]
    ]>;
    poolPrograms(overrides?: CallOverrides): Promise<[
        string[],
        BigNumber[],
        BigNumber[],
        BigNumber[],
        [
            string,
            string
        ][],
        [
            number,
            number
        ][]
    ]>;
    poolRewards(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber]>;
    providerLastClaimTime(provider: string, overrides?: CallOverrides): Promise<BigNumber>;
    providerRewards(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber, BigNumber, BigNumber, number]>;
    removePoolProgram(poolToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPoolProgramEndTime(poolToken: string, newEndTime: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updatePoolRewardsData(poolToken: string, reserveToken: string, lastUpdateTime: BigNumberish, rewardPerToken: BigNumberish, totalClaimedRewards: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateProviderLastClaimTime(provider: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateProviderRewardsData(provider: string, poolToken: string, reserveToken: string, rewardPerToken: BigNumberish, pendingBaseRewards: BigNumberish, totalClaimedRewards: BigNumberish, effectiveStakingTime: BigNumberish, baseRewardsDebt: BigNumberish, baseRewardsDebtMultiplier: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        addPoolProgram(poolToken: string, reserveTokens: [string, string], rewardShares: [BigNumberish, BigNumberish], endTime: BigNumberish, rewardRate: BigNumberish, overrides?: CallOverrides): Promise<void>;
        isPoolParticipating(poolToken: string, overrides?: CallOverrides): Promise<boolean>;
        isReserveParticipating(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<boolean>;
        poolProgram(poolToken: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            BigNumber,
            BigNumber,
            [string, string],
            [number, number]
        ]>;
        poolPrograms(overrides?: CallOverrides): Promise<[
            string[],
            BigNumber[],
            BigNumber[],
            BigNumber[],
            [
                string,
                string
            ][],
            [
                number,
                number
            ][]
        ]>;
        poolRewards(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber]>;
        providerLastClaimTime(provider: string, overrides?: CallOverrides): Promise<BigNumber>;
        providerRewards(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<[BigNumber, BigNumber, BigNumber, BigNumber, BigNumber, number]>;
        removePoolProgram(poolToken: string, overrides?: CallOverrides): Promise<void>;
        setPoolProgramEndTime(poolToken: string, newEndTime: BigNumberish, overrides?: CallOverrides): Promise<void>;
        updatePoolRewardsData(poolToken: string, reserveToken: string, lastUpdateTime: BigNumberish, rewardPerToken: BigNumberish, totalClaimedRewards: BigNumberish, overrides?: CallOverrides): Promise<void>;
        updateProviderLastClaimTime(provider: string, overrides?: CallOverrides): Promise<void>;
        updateProviderRewardsData(provider: string, poolToken: string, reserveToken: string, rewardPerToken: BigNumberish, pendingBaseRewards: BigNumberish, totalClaimedRewards: BigNumberish, effectiveStakingTime: BigNumberish, baseRewardsDebt: BigNumberish, baseRewardsDebtMultiplier: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        addPoolProgram(poolToken: string, reserveTokens: [string, string], rewardShares: [BigNumberish, BigNumberish], endTime: BigNumberish, rewardRate: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        isPoolParticipating(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        isReserveParticipating(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        poolProgram(poolToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        poolPrograms(overrides?: CallOverrides): Promise<BigNumber>;
        poolRewards(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        providerLastClaimTime(provider: string, overrides?: CallOverrides): Promise<BigNumber>;
        providerRewards(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        removePoolProgram(poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPoolProgramEndTime(poolToken: string, newEndTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updatePoolRewardsData(poolToken: string, reserveToken: string, lastUpdateTime: BigNumberish, rewardPerToken: BigNumberish, totalClaimedRewards: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateProviderLastClaimTime(provider: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateProviderRewardsData(provider: string, poolToken: string, reserveToken: string, rewardPerToken: BigNumberish, pendingBaseRewards: BigNumberish, totalClaimedRewards: BigNumberish, effectiveStakingTime: BigNumberish, baseRewardsDebt: BigNumberish, baseRewardsDebtMultiplier: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        addPoolProgram(poolToken: string, reserveTokens: [string, string], rewardShares: [BigNumberish, BigNumberish], endTime: BigNumberish, rewardRate: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        isPoolParticipating(poolToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isReserveParticipating(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        poolProgram(poolToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        poolPrograms(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        poolRewards(poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        providerLastClaimTime(provider: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        providerRewards(provider: string, poolToken: string, reserveToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        removePoolProgram(poolToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPoolProgramEndTime(poolToken: string, newEndTime: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updatePoolRewardsData(poolToken: string, reserveToken: string, lastUpdateTime: BigNumberish, rewardPerToken: BigNumberish, totalClaimedRewards: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateProviderLastClaimTime(provider: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateProviderRewardsData(provider: string, poolToken: string, reserveToken: string, rewardPerToken: BigNumberish, pendingBaseRewards: BigNumberish, totalClaimedRewards: BigNumberish, effectiveStakingTime: BigNumberish, baseRewardsDebt: BigNumberish, baseRewardsDebtMultiplier: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=IStakingRewardsStore.d.ts.map