import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "../../../common";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
export interface VortexBurnerInterface extends utils.Interface {
    functions: {
        "acceptNetworkFeeOwnership()": FunctionFragment;
        "acceptOwnership()": FunctionFragment;
        "burn(address[])": FunctionFragment;
        "burnReward()": FunctionFragment;
        "newOwner()": FunctionFragment;
        "onlyOwnerCanUpdateRegistry()": FunctionFragment;
        "owner()": FunctionFragment;
        "prevRegistry()": FunctionFragment;
        "registry()": FunctionFragment;
        "restoreRegistry()": FunctionFragment;
        "restrictRegistryUpdate(bool)": FunctionFragment;
        "setBurnReward(uint32,uint256)": FunctionFragment;
        "totalBurnedAmount()": FunctionFragment;
        "transferNetworkFeeWalletOwnership(address)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "updateRegistry()": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "acceptNetworkFeeOwnership" | "acceptOwnership" | "burn" | "burnReward" | "newOwner" | "onlyOwnerCanUpdateRegistry" | "owner" | "prevRegistry" | "registry" | "restoreRegistry" | "restrictRegistryUpdate" | "setBurnReward" | "totalBurnedAmount" | "transferNetworkFeeWalletOwnership" | "transferOwnership" | "updateRegistry"): FunctionFragment;
    encodeFunctionData(functionFragment: "acceptNetworkFeeOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "acceptOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "burn", values: [string[]]): string;
    encodeFunctionData(functionFragment: "burnReward", values?: undefined): string;
    encodeFunctionData(functionFragment: "newOwner", values?: undefined): string;
    encodeFunctionData(functionFragment: "onlyOwnerCanUpdateRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "prevRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "registry", values?: undefined): string;
    encodeFunctionData(functionFragment: "restoreRegistry", values?: undefined): string;
    encodeFunctionData(functionFragment: "restrictRegistryUpdate", values: [boolean]): string;
    encodeFunctionData(functionFragment: "setBurnReward", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "totalBurnedAmount", values?: undefined): string;
    encodeFunctionData(functionFragment: "transferNetworkFeeWalletOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "updateRegistry", values?: undefined): string;
    decodeFunctionResult(functionFragment: "acceptNetworkFeeOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "acceptOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "burn", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "burnReward", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "newOwner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "onlyOwnerCanUpdateRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "prevRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "registry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "restoreRegistry", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "restrictRegistryUpdate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setBurnReward", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalBurnedAmount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferNetworkFeeWalletOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateRegistry", data: BytesLike): Result;
    events: {
        "BurnRewardUpdated(uint32,uint32,uint256,uint256)": EventFragment;
        "Burned(address[],uint256,uint256)": EventFragment;
        "Converted(address,uint256,uint256)": EventFragment;
        "OwnerUpdate(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "BurnRewardUpdated"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Burned"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Converted"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnerUpdate"): EventFragment;
}
export interface BurnRewardUpdatedEventObject {
    prevBurnReward: number;
    newBurnReward: number;
    prevMaxBurnRewardAmount: BigNumber;
    newMaxBurnRewardAmount: BigNumber;
}
export declare type BurnRewardUpdatedEvent = TypedEvent<[
    number,
    number,
    BigNumber,
    BigNumber
], BurnRewardUpdatedEventObject>;
export declare type BurnRewardUpdatedEventFilter = TypedEventFilter<BurnRewardUpdatedEvent>;
export interface BurnedEventObject {
    reserveTokens: string[];
    sourceAmount: BigNumber;
    burnedAmount: BigNumber;
}
export declare type BurnedEvent = TypedEvent<[
    string[],
    BigNumber,
    BigNumber
], BurnedEventObject>;
export declare type BurnedEventFilter = TypedEventFilter<BurnedEvent>;
export interface ConvertedEventObject {
    reserveToken: string;
    sourceAmount: BigNumber;
    targetAmount: BigNumber;
}
export declare type ConvertedEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], ConvertedEventObject>;
export declare type ConvertedEventFilter = TypedEventFilter<ConvertedEvent>;
export interface OwnerUpdateEventObject {
    prevOwner: string;
    newOwner: string;
}
export declare type OwnerUpdateEvent = TypedEvent<[
    string,
    string
], OwnerUpdateEventObject>;
export declare type OwnerUpdateEventFilter = TypedEventFilter<OwnerUpdateEvent>;
export interface VortexBurner extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: VortexBurnerInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        acceptNetworkFeeOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        burn(reserveTokens: string[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        burnReward(overrides?: CallOverrides): Promise<[number, BigNumber]>;
        newOwner(overrides?: CallOverrides): Promise<[string]>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<[boolean]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        prevRegistry(overrides?: CallOverrides): Promise<[string]>;
        registry(overrides?: CallOverrides): Promise<[string]>;
        restoreRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setBurnReward(newBurnReward: BigNumberish, newMaxBurnRewardAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        totalBurnedAmount(overrides?: CallOverrides): Promise<[BigNumber]>;
        transferNetworkFeeWalletOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    acceptNetworkFeeOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    acceptOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    burn(reserveTokens: string[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    burnReward(overrides?: CallOverrides): Promise<[number, BigNumber]>;
    newOwner(overrides?: CallOverrides): Promise<string>;
    onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<boolean>;
    owner(overrides?: CallOverrides): Promise<string>;
    prevRegistry(overrides?: CallOverrides): Promise<string>;
    registry(overrides?: CallOverrides): Promise<string>;
    restoreRegistry(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setBurnReward(newBurnReward: BigNumberish, newMaxBurnRewardAmount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    totalBurnedAmount(overrides?: CallOverrides): Promise<BigNumber>;
    transferNetworkFeeWalletOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateRegistry(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        acceptNetworkFeeOwnership(overrides?: CallOverrides): Promise<void>;
        acceptOwnership(overrides?: CallOverrides): Promise<void>;
        burn(reserveTokens: string[], overrides?: CallOverrides): Promise<void>;
        burnReward(overrides?: CallOverrides): Promise<[number, BigNumber]>;
        newOwner(overrides?: CallOverrides): Promise<string>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<boolean>;
        owner(overrides?: CallOverrides): Promise<string>;
        prevRegistry(overrides?: CallOverrides): Promise<string>;
        registry(overrides?: CallOverrides): Promise<string>;
        restoreRegistry(overrides?: CallOverrides): Promise<void>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: CallOverrides): Promise<void>;
        setBurnReward(newBurnReward: BigNumberish, newMaxBurnRewardAmount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        totalBurnedAmount(overrides?: CallOverrides): Promise<BigNumber>;
        transferNetworkFeeWalletOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        updateRegistry(overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "BurnRewardUpdated(uint32,uint32,uint256,uint256)"(prevBurnReward?: null, newBurnReward?: null, prevMaxBurnRewardAmount?: null, newMaxBurnRewardAmount?: null): BurnRewardUpdatedEventFilter;
        BurnRewardUpdated(prevBurnReward?: null, newBurnReward?: null, prevMaxBurnRewardAmount?: null, newMaxBurnRewardAmount?: null): BurnRewardUpdatedEventFilter;
        "Burned(address[],uint256,uint256)"(reserveTokens?: null, sourceAmount?: null, burnedAmount?: null): BurnedEventFilter;
        Burned(reserveTokens?: null, sourceAmount?: null, burnedAmount?: null): BurnedEventFilter;
        "Converted(address,uint256,uint256)"(reserveToken?: null, sourceAmount?: null, targetAmount?: null): ConvertedEventFilter;
        Converted(reserveToken?: null, sourceAmount?: null, targetAmount?: null): ConvertedEventFilter;
        "OwnerUpdate(address,address)"(prevOwner?: string | null, newOwner?: string | null): OwnerUpdateEventFilter;
        OwnerUpdate(prevOwner?: string | null, newOwner?: string | null): OwnerUpdateEventFilter;
    };
    estimateGas: {
        acceptNetworkFeeOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        burn(reserveTokens: string[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        burnReward(overrides?: CallOverrides): Promise<BigNumber>;
        newOwner(overrides?: CallOverrides): Promise<BigNumber>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        prevRegistry(overrides?: CallOverrides): Promise<BigNumber>;
        registry(overrides?: CallOverrides): Promise<BigNumber>;
        restoreRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setBurnReward(newBurnReward: BigNumberish, newMaxBurnRewardAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        totalBurnedAmount(overrides?: CallOverrides): Promise<BigNumber>;
        transferNetworkFeeWalletOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        acceptNetworkFeeOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        acceptOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        burn(reserveTokens: string[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        burnReward(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        newOwner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        onlyOwnerCanUpdateRegistry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        prevRegistry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        registry(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        restoreRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        restrictRegistryUpdate(restrictOwnerOnly: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setBurnReward(newBurnReward: BigNumberish, newMaxBurnRewardAmount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        totalBurnedAmount(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transferNetworkFeeWalletOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateRegistry(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=VortexBurner.d.ts.map